@@ -7,6 +7,7 @@ Routines to search SBOMs.
 """
 
 import json
+from sbomtools.constants import FORMAT_CDX,FORMAT_SPDX
 from sbomtools.cyclonedx import cyclonedx_search
 from sbomtools.spdx import spdx_search
 
@@ -19,16 +20,16 @@ def sbom_grep(filename,search_fp,searchstr, want_json = True):
     sbom=json.loads(search_fp.read())
 
     if 'bomFormat' in sbom and sbom['bomFormat'] == 'CycloneDX':
-        res= cyclonedx_search(searchstr,sbom,want_json)
+        (state,res)= (FORMAT_CDX,cyclonedx_search(searchstr,sbom,want_json))
     if 'spdxVersion' in sbom:
-        res= spdx_search(searchstr,sbom,want_json)
+        (state,res)= (FORMAT_SPDX,spdx_search(searchstr,sbom,want_json))
     if not res:
         return False
 
-    output=''
-
     if want_json:
-        return res
+        return (state,res)
+
+    output=''
     for entry in res:
         output=output + f'{filename}: {entry["name"]} version {entry["version"]}\n'
     return output
